package com.management.platform.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.management.platform.entity.Report;
import com.management.platform.mapper.ReportMapper;
import com.management.platform.service.ReportService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.management.platform.util.HttpRespMsg;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

import javax.annotation.Resource;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-12-31
 */
@Service
public class ReportServiceImpl extends ServiceImpl<ReportMapper, Report> implements ReportService {

    @Resource
    private ReportMapper reportMapper;

    //获取报告列表
    @Override
    public HttpRespMsg getReportList(Integer pageIndex, Integer pageSize, Integer creatorId, Integer projectId,
                                     String startDate, String endDate) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        QueryWrapper<Report> queryWrapper = new QueryWrapper<>();
        if (creatorId != null) {
            queryWrapper.eq("creator_id", creatorId);
        }
        if (projectId != null) {
            queryWrapper.eq("project_id", projectId);
        }
        if (startDate != null && endDate != null) {
            queryWrapper.between("create_date",
                    LocalDate.parse(startDate, DateTimeFormatter.ofPattern("yyyy-MM-dd")),
                    LocalDate.parse(endDate, DateTimeFormatter.ofPattern("yyyy-MM-dd"))
            );
        }
        httpRespMsg.data = reportMapper.selectPage(new Page<>(pageIndex, pageSize), new QueryWrapper<>());
        return httpRespMsg;
    }

    //新增或编辑报告
    @Override
    public HttpRespMsg editReport(Report report) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        if (report.getId() == null) {
            //新增报告时 需要检查项目和人员id
            if (report.getCreatorId() == null || report.getProjectId() == null) {
                httpRespMsg.setError("请填写完整信息");
            } else {
                if (reportMapper.insert(report) == 0) {
                    httpRespMsg.setError("操作失败");
                }
            }
        } else {
            if (reportMapper.updateById(report) == 0) {
                httpRespMsg.setError("操作失败");
            }
        }
        return httpRespMsg;
    }

    //删除报告
    @Override
    public HttpRespMsg deleteReport(Integer reportId) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        if (reportMapper.deleteById(reportId) == 0) {
            httpRespMsg.setError("操作失败");
        }
        return httpRespMsg;
    }
}
