package com.management.platform.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.management.platform.entity.User;
import com.management.platform.mapper.UserMapper;
import com.management.platform.service.UserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.management.platform.util.HttpRespMsg;
import com.management.platform.util.MD5Util;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-12-31
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements UserService {
    @Resource
    private UserMapper userMapper;

    /**
     * 管理员登录网页端
     */
    @Override
    public HttpRespMsg loginAdmin(String username, String password) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        //根据电话号码获取账号信息
        List<User> userList = userMapper.selectList(new QueryWrapper<User>().eq("phone", username));
        if (userList.size() == 0) {
            //未检索到账号时
            httpRespMsg.setError("账号未注册");
        } else if (userList.size() > 1) {
            //检索到两个及以上账号时
            httpRespMsg.setError("账号重名");
        } else if (userList.get(0).getRole() != 1) {
            //检索的账号role不是1 即不是管理员时
            httpRespMsg.setError("非管理员不能登陆系统");
        } else if (MD5Util.getPassword(password).equals(userList.get(0).getPassword())) {
            //检测密码正确时
            httpRespMsg.data = userList.get(0);
        } else {
            httpRespMsg.setError("密码错误");
        }
        return httpRespMsg;
    }

    /**
     * 员工登录网页端
     */
    @Override
    public HttpRespMsg loginEmployee(String username, String password) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        //根据电话号码获取账号信息
        List<User> userList = userMapper.selectList(new QueryWrapper<User>().eq("phone", username));
        if (userList.size() == 0) {
            //未检索到账号时
            httpRespMsg.setError("账号未注册");
        } else if (userList.size() > 1) {
            //检索到两个及以上账号时
            httpRespMsg.setError("账号重名");
        } else if (userList.get(0).getRole() != 0) {
            //检索的账号role不是0 即不是普通用户时
            httpRespMsg.setError("管理员无法登陆本端");
        } else if (MD5Util.getPassword(password).equals(userList.get(0).getPassword())) {
            //检测密码正确时
            httpRespMsg.data = userList.get(0);
        } else {
            httpRespMsg.setError("密码错误");
        }
        return httpRespMsg;
    }
}
