package com.management.platform.util;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baidu.aip.util.Base64Util;

import java.net.URLEncoder;
import java.util.*;

/**
 * Author: 吴涛涛 cuiyi@itany.com
 * Date : 2019 - 08 - 30 13:59
 * Description:<描述> 百度文字识别api识别图片里的文字工具类
 * Version: 1.0
 */
public class CheckPicUtil {

    /**
     * 调用百度文字识别api识别图片里的文字
     * @param path 图片路径
     * @param token 调用百度文字识别api的access_token
     * @return 返回调用api识别出来的内容字符串
     */
    public static String general(String path,String token) {
        // 请求url
        String url = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";
        try {
            // 本地文件路径
            String filePath = path;
            byte[] imgData = FileUtil.readFileByBytes(filePath);
            String imgStr = Base64Util.encode(imgData);
            String imgParam = URLEncoder.encode(imgStr, "UTF-8");

            String param = "image=" + imgParam;

            // 注意这里仅为了简化编码每一次请求都去获取access_token，线上环境access_token有过期时间， 客户端可自行缓存，过期后重新获取。
            String accessToken = token;

            String result = HttpUtil.post(url, accessToken, param);
            System.out.println(result);
            return result;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    /**
     * 调用百度文字识别api识别图片里的文字
     * @param path 图片路径
     * @param token 调用百度文字识别api的access_token
     * @return 返回调用api识别出来的内容的List集合
     */
    public static List<String>  generalPicTextContent (String path,String token) {
        // 请求url
        String url = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";
        try {
            // 本地文件路径
            String filePath = path;
            byte[] imgData = FileUtil.readFileByBytes(filePath);
            String imgStr = Base64Util.encode(imgData);
            String imgParam = URLEncoder.encode(imgStr, "UTF-8");

            String param = "image=" + imgParam;

            // 注意这里仅为了简化编码每一次请求都去获取access_token，线上环境access_token有过期时间， 客户端可自行缓存，过期后重新获取。
            String accessToken = token;

            String result = HttpUtil.post(url, accessToken, param);
            List<String> wordsList = new ArrayList<>();
            JSONObject object = JSONArray.parseObject(result);
            JSONArray resultArray = object.getJSONArray("words_result");
            for (int i = 0; i < resultArray.size(); i++) {
                JSONObject json  = resultArray.getJSONObject(i);
                String words = (String)json.get("words");
                System.out.println("words"+i+":"+words);
                wordsList.add(words);
            }
            System.out.println(wordsList);
            return wordsList;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 调用百度文字识别api识别图片里的文字
     * @param path 图片路径
     * @param token 调用百度文字识别api的access_token
     * @return 返回调用api识别出来的内容的集合和json字符串的Map
     */
    public static Map<String,Object>  generalPicTextContentMap (String path,String token) {
        // 请求url
        String url = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";
        try {
            // 本地文件路径
            String filePath = path;
            byte[] imgData = FileUtil.readFileByBytes(filePath);
            String imgStr = Base64Util.encode(imgData);
            String imgParam = URLEncoder.encode(imgStr, "UTF-8");

            String param = "image=" + imgParam;

            // 注意这里仅为了简化编码每一次请求都去获取access_token，线上环境access_token有过期时间， 客户端可自行缓存，过期后重新获取。
            String accessToken = token;

            String result = HttpUtil.post(url, accessToken, param);
            List<String> wordsList = new ArrayList<>();
            JSONObject object = JSONArray.parseObject(result);
            JSONArray resultArray = object.getJSONArray("words_result");
            for (int i = 0; i < resultArray.size(); i++) {
                JSONObject json  = resultArray.getJSONObject(i);
                String words = (String)json.get("words");
                System.out.println("words"+i+":"+words);
                wordsList.add(words);
            }
            System.out.println(wordsList);
            Map<String,Object> map = new HashMap<>();
            map.put("wordsList",wordsList);
            map.put("picContent",object.toJSONString());
            return map;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    public static void main(String[] args) {
//        CheckPicUtil.generalPicTextContent("D:\\360MoveData\\Users\\Administrator\\Desktop\\idea.jpg",(String)AuthService.getAuth().get("access_token"));

        System.out.println("m]- IntelliJ IDEA(Administrator)".contains("Intellij IDEA"));

    }
}